@@ -1,23 +1,24 @@
 """
 Base class for all Hoppr plug-ins
 """
+from __future__ import annotations
 
 import functools
-from os import PathLike
 import subprocess
 import time
 import traceback
 
 from abc import ABC, abstractmethod
+from os import PathLike
 from typing import Any, Callable, Dict, List, Optional
 
-from packageurl import PackageURL  # type: ignore
+from packageurl import PackageURL
 
 from hoppr import plugin_utils
-from hoppr.context import Context
-from hoppr.hoppr_types.bom_access import BomAccess
-from hoppr.hoppr_types.component_coverage import ComponentCoverage
 from hoppr.mem_logger import MemoryLogger
+from hoppr.models import HopprContext
+from hoppr.models.transfer import ComponentCoverage
+from hoppr.models.types import BomAccess
 from hoppr.result import Result
 from hoppr.utils import obscure_passwords
 
@@ -154,6 +155,22 @@ def hoppr_rerunner(method: Callable) -> Callable:
     return wrapper
 
 
+def hoppr_ignore_excluded(func: Callable) -> Callable:
+    """
+    Decorator to ignore components which have a scope of `excluded`
+    """
+
+    @functools.wraps(func)
+    def wrapper(self, *args, **kwargs) -> Result:
+
+        comp = _get_component(*args, **kwargs)
+        if comp is not None and str(comp.scope) in ('excluded', 'Scope.excluded'):
+            return Result.excluded()
+        return func(self, *args, **kwargs)
+
+    return wrapper
+
+
 class HopprPlugin(ABC):
     """
     Base class for all Hoppr plug-ins
@@ -182,7 +199,7 @@ class HopprPlugin(ABC):
 
     def __init__(
         self,
-        context: Context,
+        context: HopprContext,
         config: Optional[Dict] = None,
     ) -> None:
         self._logger: MemoryLogger
@@ -235,13 +252,21 @@ class HopprPlugin(ABC):
         """
         return purl_type in self.supported_purl_types or not self.supported_purl_types
 
+    @classmethod
+    def get_attestation_products(cls, config: dict | None = None) -> list[str]:  # pylint: disable=unused-argument
+        """
+        Return a list of attestation products for this class
+        """
+
+        return cls.products
+
     def create_logger(self) -> None:
         """
         Creates a logger with a MemoryHandler, which flushes to stderr when closed
         """
         self._logger = MemoryLogger(
-            file_name=self.context.logfile_location,
-            lock=self.context.logfile_lock,
+            file_name=str(self.context.logfile_location),
+            lock=self.context.logfile_lock,  # type: ignore[arg-type]
             log_level=self.context.log_level,
         )
 
@@ -258,12 +283,8 @@ class HopprPlugin(ABC):
         self._logger.close()
 
     def run_command(
-        self,
-        command: list[str],
-        password_list: Optional[list[str]] = None,
-        cwd: Optional[str | PathLike] = None,
+        self, command: list[str], password_list: list[str] | None = None, cwd: str | PathLike[str] | None = None
     ) -> subprocess.CompletedProcess[bytes]:
-
         """
         Run a command and log any errors
         """
