@@ -51,7 +51,7 @@ class CollectAptPlugin(BatchCollectorPlugin):
 
         self.manifest_repos: list[str] = []
 
-        self.manifest_repos = [repo.url for repo in self.context.repositories[PurlType.DEB]]
+        self.manifest_repos = [f"{repo.url}" for repo in self.context.repositories[PurlType.DEB]]
 
         proxy_args = self._repo_proxy()
         self.config_dir = Path(config_dir)
@@ -133,7 +133,7 @@ class CollectAptPlugin(BatchCollectorPlugin):
         #   ("http://archive.ubuntu.com/ubuntu/pool/main/g/git/git_2.34.1-1ubuntu1.5_amd64.deb",
         #    "git_1%3a2.34.1-1ubuntu1.5_amd64.deb")
         result = url_result.stdout.decode("utf-8").split("\n")[0]
-        found_url, download_filename = result.split(" ")[0:2]
+        found_url, download_filename = result.split(" ")[:2]
 
         self.get_logger().debug(msg=f"Found URL: {found_url}", indent_level=3)
         self.get_logger().debug(msg=f"Download filename: {download_filename}", indent_level=3)
@@ -167,11 +167,7 @@ class CollectAptPlugin(BatchCollectorPlugin):
         """
         Identify the repository associated with the specified URL
         """
-        for repo in self.manifest_repos:
-            if found_url.startswith(repo):
-                return repo
-
-        return None
+        return next((repo for repo in self.manifest_repos if found_url.startswith(repo)), None)
 
     def _populate_apt_folder_structure(self, apt_path: Path, path_dict: Mapping[str, Mapping | None]) -> None:
         for key, value in path_dict.items():
@@ -193,14 +189,14 @@ class CollectAptPlugin(BatchCollectorPlugin):
         """
         Populate Apt authentication config file
         """
-        creds = []
+        creds: list[str] = []
         for repo in repo_list:
-            repo_credentials = Credentials.find(repo.url)
+            repo_credentials = Credentials.find(f"{repo.url}")
             if repo_credentials is not None:
                 creds.append(
-                    f"machine {urlparse(repo.url).netloc} "
+                    f"machine {repo.url.hostname} "
                     f"login {repo_credentials.username} "
-                    f"password {repo_credentials.password}\n"
+                    f"password {repo_credentials.password.get_secret_value()}\n"
                 )
 
         # Set restrictive permissions on Apt authentication config file
@@ -221,12 +217,16 @@ class CollectAptPlugin(BatchCollectorPlugin):
 
         version_codename = parser["os-release"]["VERSION_CODENAME"]
 
-        sources = []
+        sources: list[str] = []
         for repo in repo_list:
             for component in ["main restricted", "universe", "multiverse"]:
-                sources.append(f"deb {repo} {version_codename} {component}")
-                sources.append(f"deb {repo} {version_codename}-updates {component}")
-                sources.append(f"deb {repo} {version_codename}-security {component}")
+                sources.extend(
+                    (
+                        f"deb {repo} {version_codename} {component}",
+                        f"deb {repo} {version_codename}-updates {component}",
+                        f"deb {repo} {version_codename}-security {component}",
+                    )
+                )
 
         with file.open(mode="w+", encoding="utf-8") as sources_list:
             sources_list.write("\n".join(sources))
@@ -235,8 +235,7 @@ class CollectAptPlugin(BatchCollectorPlugin):
         proxy_args: list[str] = []
 
         for proto in ["http", "https"]:
-            proxy = os.getenv(f"{proto}_proxy")
-            if proxy:
+            if proxy := os.getenv(f"{proto}_proxy"):
                 proxy_args = [*proxy_args, f"--option=Acquire::{proto}::Proxy={proxy}"]
 
         no_proxy_urls = [item for item in os.getenv("no_proxy", "").split(",") if item != ""]
