@@ -3,10 +3,7 @@ Collector plugin for helm charts
 """
 from __future__ import annotations
 
-import re
-
 from pathlib import Path
-from urllib.parse import urljoin
 
 from packageurl import PackageURL
 
@@ -17,6 +14,7 @@ from hoppr.exceptions import HopprLoadDataError
 from hoppr.models import HopprContext
 from hoppr.models.credentials import CredentialRequiredService
 from hoppr.models.manifest import Component
+from hoppr.models.types import RepositoryUrl
 from hoppr.result import Result
 
 
@@ -68,13 +66,10 @@ class CollectHelmPlugin(SerialCollectorPlugin):
 
         purl: PackageURL = PackageURL.from_string(comp.purl)  # pyright: ignore[reportGeneralTypeIssues]
 
-        if not re.match(pattern="^.*/$", string=repo_url):
-            repo_url = f"{repo_url}/"
-
         target_dir = self.directory_for(purl.type, repo_url, subdir=f"{purl.name}_{purl.version}")
 
         for subdir in ["", purl.name]:
-            source_url = urljoin(base=repo_url, url=subdir)
+            source_url = RepositoryUrl(url=repo_url) / subdir
 
             self.get_logger().info(msg="Fetching helm chart:", indent_level=2)
             self.get_logger().info(msg=f"source: {source_url}", indent_level=3)
@@ -83,7 +78,7 @@ class CollectHelmPlugin(SerialCollectorPlugin):
             command = [
                 *self.base_command,
                 "--repo",
-                source_url,
+                f"{source_url}",
                 "--destination",
                 f"{target_dir}",
                 purl.name,
