@@ -3,27 +3,24 @@ Collector plugin for maven artifacts
 """
 from __future__ import annotations
 
-from copy import deepcopy
 import os
+
 from pathlib import Path
 from subprocess import CalledProcessError
 from tempfile import NamedTemporaryFile
 from typing import Any, OrderedDict
 
-import jmespath  # type: ignore[import]
-import xmltodict  # type: ignore[import]
+import jmespath
+import xmltodict
 
-from hoppr_cyclonedx_models.cyclonedx_1_4 import Component
-from packageurl import PackageURL  # type: ignore[import]
+from packageurl import PackageURL
 
 from hoppr import __version__
 from hoppr.base_plugins.collector import SerialCollectorPlugin
 from hoppr.base_plugins.hoppr import hoppr_rerunner
-from hoppr.context import Context
-from hoppr.flatten_sboms import flatten_sboms
-from hoppr.hoppr_types.cred_object import CredObject
-from hoppr.hoppr_types.manifest_file_content import Repository
-from hoppr.hoppr_types.purl_type import PurlType
+from hoppr.models import HopprContext
+from hoppr.models.credentials import CredentialRequiredService
+from hoppr.models.manifest import Component
 from hoppr.result import Result
 
 _MAVEN_DEP_PLUGIN = "org.apache.maven.plugins:maven-dependency-plugin:3.5.0"
@@ -37,11 +34,12 @@ class CollectMavenPlugin(SerialCollectorPlugin):
     supported_purl_types = ["maven"]
     required_commands = ["mvn"]
     products: list[str] = ["maven/*"]
+    system_repositories: list[str] = ["https://repo.maven.apache.org/maven2"]
 
     def get_version(self) -> str:  # pylint: disable=duplicate-code
         return __version__
 
-    def __init__(self, context: Context, config: dict | None = None) -> None:
+    def __init__(self, context: HopprContext, config: dict | None = None) -> None:
         super().__init__(context=context, config=config)
 
         self.extra_opts: list[str] = []
@@ -54,7 +52,8 @@ class CollectMavenPlugin(SerialCollectorPlugin):
         user_settings_file = Path.home() / ".m2" / "settings.xml"
 
         if not self.context.strict_repos:
-            # Add system repositories to manifest
+
+            # Identify system repositories
             for settings_file in [system_settings_file, user_settings_file]:
                 if settings_file.is_file():
                     settings_dict: OrderedDict[str, Any] = xmltodict.parse(
@@ -64,17 +63,12 @@ class CollectMavenPlugin(SerialCollectorPlugin):
                     )
 
                     repo_urls: list[str] = jmespath.search(
-                        expression="settings.profiles.profile[].repositories.repository[].url",
-                        data=settings_dict,
+                        expression="settings.profiles.profile[].repositories.repository[].url", data=settings_dict
                     )
 
-                    for repo_url in repo_urls:
-                        self.context.manifest.consolidated_repositories[PurlType.MAVEN].append(
-                            Repository(url=repo_url, description="")
-                        )
-
-                self.context.consolidated_sbom = flatten_sboms(self.context.manifest)
-                self.context.delivered_sbom = deepcopy(self.context.consolidated_sbom)
+                    for repo in repo_urls:
+                        if repo not in self.system_repositories:
+                            self.system_repositories.append(repo)
 
     def _get_maven_component(self, command: list[str], password_list: list[str], **kwargs):
         full_command = command.copy()
@@ -95,20 +89,15 @@ class CollectMavenPlugin(SerialCollectorPlugin):
         return result
 
     @hoppr_rerunner
-    def collect(self, comp: Component, repo_url: str, creds: CredObject | None = None) -> Result:
+    def collect(self, comp: Component, repo_url: str, creds: CredentialRequiredService | None = None) -> Result:
         """
         Copy a component to the local collection directory structure
         """
         # pylint: disable=too-many-locals
 
-        purl = PackageURL.from_string(comp.purl)
+        purl: PackageURL = PackageURL.from_string(comp.purl)  # pyright: ignore[reportGeneralTypeIssues]
         artifact = f"{purl.namespace}:{purl.name}:{purl.version}"
 
-        if self.context.strict_repos:
-            result = self.check_purl_specified_url(purl, repo_url)  # type: ignore
-            if not result.is_success():
-                return result
-
         extension = purl.qualifiers.get("type", "tar.gz")
         target_dir = self.directory_for(purl.type, repo_url, subdir=f"{purl.namespace}")
 
@@ -143,8 +132,8 @@ class CollectMavenPlugin(SerialCollectorPlugin):
 
             if creds is not None:
                 defines["repo.login"] = creds.username
-                defines["repo.pwd"] = creds.password
-                password_list = [creds.password]
+                defines["repo.pwd"] = creds.password.get_secret_value()
+                password_list = [creds.password.get_secret_value()]
 
             command = [
                 self.required_commands[0],
@@ -170,4 +159,6 @@ class CollectMavenPlugin(SerialCollectorPlugin):
                 self.get_logger().debug(msg=error_msg, indent_level=2)
                 return Result.retry(message=error_msg)
 
-        return Result.success()
+        self.set_collection_params(comp, repo_url, target_dir)
+
+        return Result.success(return_obj=comp)
