@@ -8,7 +8,6 @@ import re
 import sys
 
 from subprocess import CalledProcessError
-from urllib.parse import ParseResult, urljoin, urlparse
 
 from packageurl import PackageURL
 
@@ -18,6 +17,7 @@ from hoppr.base_plugins.hoppr import hoppr_rerunner
 from hoppr.models import HopprContext
 from hoppr.models.credentials import CredentialRequiredService
 from hoppr.models.manifest import Component
+from hoppr.models.types import RepositoryUrl
 from hoppr.result import Result
 
 
@@ -77,16 +77,18 @@ class CollectPypiPlugin(SerialCollectorPlugin):
 
         purl = PackageURL.from_string(comp.purl)
 
-        source_url = repo_url
-        if not re.match(pattern="^.*simple/?$", string=source_url):
-            source_url = urljoin(base=source_url, url="simple")
+        source_url = RepositoryUrl(url=repo_url)
+        if not re.match(pattern="^.*simple/?$", string=f"{source_url}"):
+            source_url /= "simple"
 
         password_list = []
 
         if creds is not None:
-            parsed_url = urlparse(url=source_url)._asdict()
-            parsed_url["netloc"] = f"{creds.username}:{creds.password.get_secret_value()}@{parsed_url['netloc']}"
-            source_url = ParseResult(**parsed_url).geturl()
+            source_url = RepositoryUrl(
+                url=source_url.url,
+                username=creds.username,
+                password=creds.password.get_secret_value(),
+            )
             password_list = [creds.password.get_secret_value()]
 
         target_dir = self.directory_for(purl.type, repo_url, subdir=f"{purl.name}_{purl.version}")
@@ -101,7 +103,7 @@ class CollectPypiPlugin(SerialCollectorPlugin):
             "--timeout",
             "60",
             "--index-url",
-            source_url,
+            f"{source_url}",
             "--dest",
             f"{target_dir}",
             f"{purl.name}=={purl.version}",
