@@ -10,10 +10,10 @@ from typing import List, Optional
 from typer import Exit, echo, prompt
 
 from hoppr import __version__
-from hoppr.configs.credentials import Credentials
-from hoppr.configs.manifest import Manifest
-from hoppr.configs.transfer import Transfer
 from hoppr.in_toto import generate_in_toto_layout
+from hoppr.models.credentials import Credentials
+from hoppr.models.manifest import Manifest
+from hoppr.models.transfer import Transfer
 from hoppr.processor import HopprProcessor
 
 
@@ -28,20 +28,17 @@ def bundle(  # pylint: disable=too-many-arguments,too-many-locals
     functionary_key_path: Optional[Path] = None,
     functionary_key_prompt: bool = False,
     functionary_key_password: Optional[str] = None,
+    previous_delivery: Optional[Path] = None,
 ):
     """
     Run the stages specified in the transfer config
     file on the content specified in the manifest
     """
-
     metadata_files = [manifest_file, transfer_file]
 
     if credentials_file is not None:
-        Credentials.load_file(file=credentials_file)
         metadata_files.append(credentials_file)
 
-    manifest = Manifest.load_file(file=manifest_file)
-    transfer = Transfer.load_file(file=transfer_file)
     log_level = logging.DEBUG if verbose else logging.INFO
 
     if create_attestations and functionary_key_path is None:
@@ -52,16 +49,21 @@ def bundle(  # pylint: disable=too-many-arguments,too-many-locals
         functionary_key_password = prompt(f"Enter password for {str(functionary_key_path)}", hide_input=True)
 
     processor = HopprProcessor(
-        transfer=transfer,
-        manifest=manifest,
+        transfer_file=transfer_file,
+        manifest_file=manifest_file,
+        credentials_file=credentials_file,
         create_attestations=create_attestations,
         functionary_key_path=functionary_key_path,
         functionary_key_password=functionary_key_password,
         log_level=log_level,
+        log_file=log_file,
+        strict_repos=strict_repos,
+        previous_delivery=previous_delivery,
     )
+
     processor.metadata_files = metadata_files
 
-    result = processor.run(log_file=log_file, strict_repos=strict_repos)
+    result = processor.run()
 
     if result.is_fail():
         sys.exit(1)
@@ -81,26 +83,20 @@ def generate_layout(
     if project_owner_key_prompt:
         project_owner_key_password = prompt(f"Enter password for {str(project_owner_key_path)}", hide_input=True)
 
-    transfer = Transfer.load_file(file=transfer_file)
+    transfer = Transfer.load(transfer_file)
     generate_in_toto_layout(transfer, project_owner_key_path, functionary_key_path, project_owner_key_password)
 
 
-def validate(
-    input_files: List[Path],
-    credentials_file: Path,
-    transfer_file: Path,
-):
+def validate(input_files: List[Path], credentials_file: Path, transfer_file: Path):
     """
     Validate multiple manifest files for schema errors.
     """
 
-    cred_config = None
-    transfer_config = None  # pylint: disable=unused-variable
-    manifests = []  # pylint: disable=unused-variable
-
     if credentials_file is not None:
-        cred_config = Credentials.load_file(credentials_file)
-    if transfer_file is not None:
-        transfer_config = Transfer.load_file(transfer_file)
+        Credentials.load(credentials_file)
 
-    manifests = [Manifest.load_file(file, cred_config) for file in input_files]
+    if transfer_file is not None:
+        Transfer.load(transfer_file)
+
+    for file in input_files:
+        Manifest.load(file)
