@@ -26,7 +26,7 @@ import hoppr.utils
 from hoppr.constants import BomProps
 from hoppr.exceptions import HopprLoadDataError
 from hoppr.models.base import HopprBaseModel, HopprBaseSchemaModel
-from hoppr.models.types import PurlType
+from hoppr.models.types import PurlType, RepositoryUrl
 
 if TYPE_CHECKING:
     from pydantic.typing import DictStrAny
@@ -37,9 +37,20 @@ class Repository(HopprBaseModel):
     Repository data model
     """
 
-    url: HttpUrl | FileUrl | AnyUrl
+    url: RepositoryUrl
     description: NoneStr = None
 
+    @validator("url", pre=True)
+    @classmethod
+    def validate_url(cls, url: str | RepositoryUrl) -> RepositoryUrl:
+        """
+        Validate URL string
+        """
+        if isinstance(url, str):
+            url = RepositoryUrl(url=url)
+
+        return url
+
 
 # Dynamic Repositories model with PurlType values as attribute names
 purl_type_repo_mapping = {str(purl_type): (list[Repository], Field([], unique_items=True)) for purl_type in PurlType}
@@ -104,6 +115,7 @@ Includes = Annotated[list[IncludeRef], Field(..., description="List of manifest
 SbomRef = Annotated[LocalFile | OciFile | UrlFile, Field(..., description="Reference to a local or remote SBOM file")]
 Sboms = Annotated[list[SbomRef], Field(..., description="List of SBOMs to process")]
 SbomRefMap = Annotated[MutableMapping[SbomRef, "Sbom"], Field(...)]
+ComponentPurlMap = Annotated[MutableMapping[str, "Component"], Field(...)]
 
 
 class ExternalReference(HopprBaseModel, ExternalReferenceSpecVersion14):
@@ -135,6 +147,22 @@ class Component(HopprBaseModel, ComponentSpecVersion14):
     externalReferences: list[ExternalReference] | None = Field(None)  # type: ignore[assignment]
     properties: list[Property] | None = Field(None)  # type: ignore[assignment]
 
+    # Attributes not included in schema
+    component_lookup: ClassVar[ComponentPurlMap] = {}
+
+    @classmethod
+    def find(cls, purl_string: str) -> Component | None:
+        """
+        Look up Component object by package URL string
+
+        Args:
+            purl_string (str): Package URL string to look up
+
+        Returns:
+            Component | None: Component object if found, otherwise None
+        """
+        return cls.component_lookup.get(purl_string)
+
 
 class Sbom(HopprBaseModel, SbomSpecVersion14):
     """
@@ -156,7 +184,7 @@ class Sbom(HopprBaseModel, SbomSpecVersion14):
     @classmethod
     def find(cls, ref_type: Literal["local", "oci", "url"], location: str | Path) -> Sbom | None:
         """
-        Lookup SBOM object by reference
+        Look up SBOM object by reference
 
         Args:
             ref_type (Literal["local", "oci", "url"]): Type of SBOM reference
@@ -320,7 +348,7 @@ class Manifest(ManifestFile):
                     if purl_str is None:
                         continue
 
-                    purl_type = PackageURL.from_string(purl_str).type
+                    purl_type = hoppr.utils.get_package_url(purl_str).type
 
                     if component.properties is None:
                         component.properties = []
@@ -355,33 +383,26 @@ class Manifest(ManifestFile):
     @classmethod
     def _add_component(cls, component: Component) -> None:
         # Remove purl qualifiers for later comparison
-        purl: PackageURL = PackageURL.from_string(component.purl)  # pyright: ignore[reportGeneralTypeIssues]
+        purl: PackageURL = hoppr.utils.get_package_url(component.purl)
         purl.qualifiers.clear()
         purl_str = purl.to_string()
 
-        # Check previously loaded components for component to be added
-        for loaded in Sbom.consolidated_sbom.components:
-            loaded_purl: PackageURL = PackageURL.from_string(loaded.purl)  # pyright: ignore[reportGeneralTypeIssues]
-            loaded_purl.qualifiers.clear()
-            loaded_purl_str = loaded_purl.to_string()
-
-            if loaded.externalReferences is None:
-                loaded.externalReferences = []  # pragma: no cover
+        loaded = Component.find(purl_str)
+        # Merge component into previously loaded component
+        if loaded is not None:
+            loaded.externalReferences = hoppr.utils.dedup_list(
+                [*(loaded.externalReferences or []), *(component.externalReferences or [])]
+            )
 
             if loaded.properties is None:
                 loaded.properties = []  # pragma: no cover
 
-            if purl_str == loaded_purl_str:
-                # Merge component into previously loaded component
-                loaded.externalReferences = list(set(loaded.externalReferences + (component.externalReferences or [])))
-
-                for prop in component.properties or []:
-                    if prop.name not in [loaded_prop.name for loaded_prop in loaded.properties]:
-                        loaded.properties.append(prop)
-
-                return
-
-        Sbom.consolidated_sbom.components.append(Component.parse_obj(component))
+            for prop in component.properties or []:
+                if prop.name not in [loaded_prop.name for loaded_prop in loaded.properties]:
+                    loaded.properties.append(prop)
+        else:
+            Sbom.consolidated_sbom.components.append(component)
+            Component.component_lookup[purl_str] = component
 
     @classmethod
     def _get_ref_url(cls, sbom_ref: SbomRef) -> str | None:
