@@ -4,14 +4,13 @@ import re
 from pathlib import Path
 from typing import Dict, Tuple
 
-import oras.client  # type: ignore
-
-from oras.container import Container  # type: ignore
-from oras.provider import Registry  # type: ignore
+from oras.client import OrasClient  # type: ignore[import]
+from oras.container import Container  # type: ignore[import]
+from oras.provider import Registry  # type: ignore[import]
 
 from hoppr import utils
-from hoppr.configs.credentials import Credentials
 from hoppr.exceptions import HopprLoadDataError
+from hoppr.models.credentials import Credentials
 
 # Regex per: https://semver.org/#is-there-a-suggested-regular-expression-regex-to-check-a-semver-string
 SEM_VER_CORE_REGEX = r"^(0|[1-9]\d*)\.(0|[1-9]\d*)\.(0|[1-9]\d*)$"
@@ -59,16 +58,16 @@ def pull_artifact_to_disk(
     )
 
 
-def _create_client_info(artifact: str) -> Tuple[Container, oras.client.OrasClient]:
+def _create_client_info(artifact: str) -> Tuple[Container, OrasClient]:
     """Utility function for creating ORAS client and intermediate objects"""
     # Use ORAS' Container object to faciliate parsing registry host
     container = Container(artifact)
     registry = Registry(hostname=container.registry)
 
-    creds = Credentials.find_credentials(container.registry)
+    creds = Credentials.find(container.registry)
     if creds is not None:
-        registry.set_basic_auth(creds.username, creds.password)
-    client = oras.client.OrasClient(registry=registry)
+        registry.set_basic_auth(creds.username, creds.password.get_secret_value())
+    client = OrasClient(registry=registry)
 
     return container, client
 
@@ -102,10 +101,10 @@ def _discover_highest_version_tag(artifact: str, version_regex=SEM_VER_CORE_REGE
     regex. Default will use full SemVer"""
     container, client = _create_client_info(artifact)
 
-    tags = client.get_tags(container)
+    tags: list[str] = client.get_tags(str(container))
 
     # Only find those that match semver
     # Future enhancement can allow user to define regex to use in the artifact definition
-    tags = sorted(filter(lambda x: re.match(version_regex, x), tags["tags"]))
+    tags = sorted(filter(lambda x: re.match(version_regex, x), tags["tags"]))  # type: ignore[arg-type,call-overload]
 
     return sorted(tags)[-1]
