@@ -7,10 +7,12 @@ import importlib
 import inspect
 
 from abc import ABCMeta
+from functools import cache
 from pathlib import Path
 from types import ModuleType
 from typing import TYPE_CHECKING, Any, Type
 
+from packageurl import PackageURL
 from ruamel.yaml import YAML
 from ruamel.yaml.parser import ParserError as YAMLParserError
 from ruamel.yaml.scanner import ScannerError as YAMLScannerError
@@ -163,3 +165,18 @@ def remove_empty(directory: Path) -> set[Path]:
         deleted.add(directory)
 
     return deleted
+
+
+@cache
+def get_package_url(purl_string: str) -> PackageURL:
+    """
+    Get the PackageURL for a given purl_string and store it in a cache for improved performance.
+
+    Args:
+        purl_string (str): The string representation of a Package URL
+
+    Returns:
+        PackageURL: The object representation of a PackageURL
+
+    """
+    return PackageURL.from_string(purl_string)  # pyright: ignore[reportGeneralTypeIssues]
